=== modified file 'plugin/session_dictionary/dictionary.cc'
--- plugin/session_dictionary/dictionary.cc	2010-11-13 03:36:33 +0000
+++ plugin/session_dictionary/dictionary.cc	2010-11-16 22:52:43 +0000
@@ -27,6 +27,7 @@
 {
   context.add(new ProcesslistTool);
   context.add(new session_dictionary::Variables);
+  context.add(new session_dictionary::Savepoints);
   
   return 0;
 }

=== modified file 'plugin/session_dictionary/dictionary.h'
--- plugin/session_dictionary/dictionary.h	2010-11-13 03:36:33 +0000
+++ plugin/session_dictionary/dictionary.h	2010-11-16 22:52:43 +0000
@@ -23,6 +23,7 @@
 
 #include "drizzled/plugin/table_function.h"
 #include "plugin/session_dictionary/processlist.h"
+#include "plugin/session_dictionary/savepoints.h"
 #include "plugin/session_dictionary/variables.h"
 
 #endif /* PLUGIN_SESSION_DICTIONARY_DICTIONARY_H */

=== modified file 'plugin/session_dictionary/plugin.ini'
--- plugin/session_dictionary/plugin.ini	2010-11-13 03:36:33 +0000
+++ plugin/session_dictionary/plugin.ini	2010-11-16 22:52:43 +0000
@@ -5,9 +5,11 @@
 sources=
   dictionary.cc
   processlist.cc
+  savepoints.cc
   variables.cc
 headers=
   dictionary.h
   processlist.h
+  savepoints.h
   variables.h
 static=yes

=== added file 'plugin/session_dictionary/savepoints.cc'
--- plugin/session_dictionary/savepoints.cc	1970-01-01 00:00:00 +0000
+++ plugin/session_dictionary/savepoints.cc	2010-11-16 22:52:43 +0000
@@ -0,0 +1,59 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "plugin/session_dictionary/dictionary.h"
+
+namespace session_dictionary {
+
+Savepoints::Savepoints() :
+  drizzled::plugin::TableFunction("DATA_DICTIONARY", "USER_SAVEPOINTS")
+{
+  add_field("SAVEPOINT_NAME", drizzled::plugin::TableFunction::STRING, LARGEST_USER_VARIABLE_NAME, false);
+}
+
+Savepoints::Generator::Generator(drizzled::Field **arg) :
+  drizzled::plugin::TableFunction::Generator(arg),
+  savepoints(getSession().transaction.savepoints),
+  iter(savepoints.begin())
+{
+}
+
+Savepoints::Generator::~Generator()
+{
+}
+
+bool Savepoints::Generator::populate()
+{
+  while (iter != savepoints.end())
+  {
+    // SAVEPOINT_NAME
+    push((*iter).getName());
+
+    iter++;
+
+    return true;
+  }
+
+  return false;
+}
+
+} /* namespace session_dictionary */

=== added file 'plugin/session_dictionary/savepoints.h'
--- plugin/session_dictionary/savepoints.h	1970-01-01 00:00:00 +0000
+++ plugin/session_dictionary/savepoints.h	2010-11-16 22:52:43 +0000
@@ -0,0 +1,52 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_SESSION_DICTIONARY_SAVEPOINTS_H
+#define PLUGIN_SESSION_DICTIONARY_SAVEPOINTS_H
+
+namespace session_dictionary {
+
+class Savepoints : public drizzled::plugin::TableFunction
+{
+public:
+
+  Savepoints();
+
+  class Generator : public drizzled::plugin::TableFunction::Generator 
+  {
+    std::deque<drizzled::NamedSavepoint> &savepoints;
+    std::deque<drizzled::NamedSavepoint>::const_iterator iter;
+
+  public:
+    Generator(drizzled::Field **arg);
+    ~Generator();
+
+    bool populate();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+};
+
+} /* namespace session_dictionary */
+
+#endif /* PLUGIN_SESSION_DICTIONARY_SAVEPOINTS_H */

=== added file 'plugin/session_dictionary/tests/r/user_savepoints.result'
--- plugin/session_dictionary/tests/r/user_savepoints.result	1970-01-01 00:00:00 +0000
+++ plugin/session_dictionary/tests/r/user_savepoints.result	2010-11-16 22:52:43 +0000
@@ -0,0 +1,64 @@
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo
+release savepoint foo;
+rollback;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo
+savepoint foo2;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo2
+foo
+rollback;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo
+savepoint foo2;
+release savepoint foo;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo2
+rollback;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo
+savepoint foo2;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo2
+foo
+release savepoint foo2;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo
+rollback;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+start transaction;
+savepoint foo;
+savepoint foo2;
+savepoint foo3;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME
+foo3
+foo2
+foo
+commit;
+select * from data_dictionary.user_savepoints;
+SAVEPOINT_NAME

=== added file 'plugin/session_dictionary/tests/t/user_savepoints.test'
--- plugin/session_dictionary/tests/t/user_savepoints.test	1970-01-01 00:00:00 +0000
+++ plugin/session_dictionary/tests/t/user_savepoints.test	2010-11-16 22:52:43 +0000
@@ -0,0 +1,43 @@
+# List savepoints.
+
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+release savepoint foo;
+rollback;
+select * from data_dictionary.user_savepoints;
+
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+savepoint foo2;
+select * from data_dictionary.user_savepoints;
+rollback;
+select * from data_dictionary.user_savepoints;
+
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+savepoint foo2;
+release savepoint foo;
+select * from data_dictionary.user_savepoints;
+rollback;
+select * from data_dictionary.user_savepoints;
+
+start transaction;
+savepoint foo;
+select * from data_dictionary.user_savepoints;
+savepoint foo2;
+select * from data_dictionary.user_savepoints;
+release savepoint foo2;
+select * from data_dictionary.user_savepoints;
+rollback;
+select * from data_dictionary.user_savepoints;
+
+start transaction;
+savepoint foo;
+savepoint foo2;
+savepoint foo3;
+select * from data_dictionary.user_savepoints;
+commit;
+select * from data_dictionary.user_savepoints;

